<?php

/**
 * @file
 * Shipwire module administration menu and callbacks.
 */


/**
 * Settings form for Shipwire integration.
 *
 * Records Shipwire account information necessary to use service. Allows
 * testing or production mode.
 *
 * @return
 *   Forms for store administrator to set configuration options.
 *
 * @see uc_shipwire_admin_settings_validate()
 * @ingroup forms
 */
function uc_shipwire_admin_settings() {
  $form = array();

  // Put fieldsets into vertical tabs
  $form['shipwire-settings'] = array(
    '#type' => 'vertical_tabs',
    '#attached' => array(
      'js' => array(
        'vertical-tabs' => drupal_get_path('module', 'uc_shipwire') . '/uc_shipwire.admin.js',
      ),
    ),
  );

  // Container for credentials forms
  $form['uc_shipwire_credentials'] = array(
    '#type'          => 'fieldset',
    '#title'         => t('Credentials'),
    '#description'   => t('Account number and authorization information.'),
    '#collapsible'   => TRUE,
    '#collapsed'     => TRUE,
    '#group'         => 'shipwire-settings',
  );

  // Form to set user e-mail address
  $form['uc_shipwire_credentials']['uc_shipwire_username'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Email address'),
    '#description'   => t('The email address corresponding to the Shipwire account.'),
    '#default_value' => variable_get('uc_shipwire_username', ''),
    '#required'      => TRUE,
  );

  // Form to set user password
  $form['uc_shipwire_credentials']['uc_shipwire_password'] = array(
    '#type'          => 'password',
    '#title'         => t('Password'),
    '#description'   => t('Password for the shipwire account.'),
    '#default_value' => variable_get('uc_shipwire_password', ''),
  );

  // Form to set choose between Production and Testing server
  // ***Defaults to Testing!***
  $form['uc_shipwire_credentials']['uc_shipwire_server'] = array(
    '#type'          => 'select',
    '#title'         => t('Server'),
    '#description'   => t('This should be set to "Production" to use the live environment.'),
    '#options'       => array(
      'testing'      => t('Testing'),
      'production'   => t('Production'),
    ),
    '#default_value' => variable_get('uc_shipwire_server', 'testing'),
    '#required'      => TRUE,
  );

  // Register additional validation handler
  $form['#validate'][] = 'uc_shipwire_admin_settings_validate';

  $form = system_settings_form($form);

  // Add Cancel link
  $form['actions']['cancel'] = array(
    '#markup' => l(t('Cancel'), 'admin/store/settings/quotes'),
  );

  return $form;
}

/**
 * Validation handler for uc_shipwire_admin_settings form.
 *
 * Requires password only if it hasn't been set.
 *
 * @see uc_shipwire_admin_settings()
 */
function uc_shipwire_admin_settings_validate($form, &$form_state) {

  $old_password = variable_get('uc_shipwire_password', '');
  if (!$form_state['values']['uc_shipwire_password']) {
    if ($old_password) {
      form_set_value($form['uc_shipwire_credentials']['uc_shipwire_password'], $old_password, $form_state);
    }
    else {
      form_set_error('uc_shipwire_password', t('Password field is required.'));
    }
  }
}
